```@meta
CurrentModule = Mosek
```



This page lists all MOSEK functions available from Julia. Please note that the documentation was generated from the documentation for the MOSEK C API, so in some cases it may be slightly invalid. Specifically,
* Index arguments may not be displayed or documented as starting at 1 (indexes in C start at 0). Nevertheless, in the MOSEK Julia API all indexes are 1-based.
* Values that are returned from functions may be documented as if they appeared in the argument list for functions.
* Probably a lot of other stuff. I will be trying to improve all this when I can.

For most functions there are two alternatives; one where all arguments are
structly typed, and one where most arguments are untyped. The latter will
convert arguments as necessary and call the former, but there appears to be a
significant overhead in doing this. To improve efficiency it may be a good idea to 
make sure that arguments have the correct types so the typed function is called.

For more verbose descriptions of the individual functions, it is a good idea to
look at e.g. the Python documentation at [MOSEK docs](http://docs.mosek.com).
      

# Mosek.jl Functions

```@docs
analyzenames
analyzeproblem
analyzesolution
appendbarvars
appendcone
appendconeseq
appendconesseq
appendcons
appendsparsesymmat
appendsparsesymmatlist
appendvars
basiscond
bktostr
callbackcodetostr
checkconvexity
checkinall
checkinlicense
checkmem
checkoutlicense
chgconbound
chgvarbound
commitchanges
conetypetostr
deletesolution
dualsensitivity
echointro
generateconenames
generateconnames
generatevarnames
getacol
getacolnumnz
getacolslice
getacolslicenumnz
getacolslicetrip
getaij
getapiecenumnz
getarow
getarownumnz
getarowslice
getarowslicenumnz
getarowslicetrip
getatruncatetol
getbarablocktriplet
getbaraidx
getbaraidxij
getbaraidxinfo
getbarasparsity
getbarcblocktriplet
getbarcidx
getbarcidxinfo
getbarcidxj
getbarcsparsity
getbarsj
getbarsslice
getbarvarname
getbarvarnameindex
getbarvarnamelen
getbarxj
getbarxslice
getc
getcfix
getcj
getclist
getcodedesc
getconbound
getconboundslice
getcone
getconeinfo
getconename
getconenameindex
getconenamelen
getconname
getconnameindex
getconnamelen
getcslice
getdimbarvarj
getdouinf
getdouparam
getdualobj
getdualsolutionnorms
getdviolbarvar
getdviolcon
getdviolcones
getdviolvar
getinfeasiblesubproblem
getinfname
getintinf
getintparam
getlenbarvarj
getlintinf
getmaxnumanz
getmaxnumbarvar
getmaxnumcon
getmaxnumcone
getmaxnumqnz
getmaxnumvar
getmemusage
getnadouinf
getnadouparam
getnaintinf
getnaintparam
getnastrparam
getnumanz
getnumanz64
getnumbarablocktriplets
getnumbaranz
getnumbarcblocktriplets
getnumbarcnz
getnumbarvar
getnumcon
getnumcone
getnumconemem
getnumintvar
getnumparam
getnumqconknz
getnumqobjnz
getnumsymmat
getnumvar
getobjname
getobjnamelen
getobjsense
getparamname
getprimalobj
getprimalsolutionnorms
getprobtype
getprosta
getpviolbarvar
getpviolcon
getpviolcones
getpviolvar
getqconk
getqobj
getqobjij
getreducedcosts
getskc
getskcslice
getskn
getskx
getskxslice
getslc
getslcslice
getslx
getslxslice
getsnx
getsnxslice
getsolsta
getsolution
getsolutioninfo
getsolutionslice
getsparsesymmat
getstrparam
getstrparamlen
getsuc
getsucslice
getsux
getsuxslice
getsymmatinfo
gettaskname
gettasknamelen
getvarbound
getvarboundslice
getvarname
getvarnameindex
getvarnamelen
getvartype
getvartypelist
getversion
getxc
getxcslice
getxx
getxxslice
gety
getyslice
initbasissolve
inputdata
isdouparname
isintparname
isstrparname
licensecleanup
linkfiletostream
onesolutionsummary
optimize
optimizermt
optimizersummary
primalrepair
primalsensitivity
printparam
putacol
putacollist
putacolslice
putaij
putaijlist
putarow
putarowlist
putarowslice
putatruncatetol
putbarablocktriplet
putbaraij
putbaraijlist
putbararowlist
putbarcblocktriplet
putbarcj
putbarsj
putbarvarname
putbarxj
putcfix
putcj
putclist
putconbound
putconboundlist
putconboundlistconst
putconboundslice
putconboundsliceconst
putcone
putconename
putconname
putconsolutioni
putcslice
putdouparam
putintparam
putlicensecode
putlicensedebug
putlicensepath
putlicensewait
putmaxnumanz
putmaxnumbarvar
putmaxnumcon
putmaxnumcone
putmaxnumqnz
putmaxnumvar
putnadouparam
putnaintparam
putnastrparam
putobjname
putobjsense
putparam
putqcon
putqconk
putqobj
putqobjij
putskc
putskcslice
putskx
putskxslice
putslc
putslcslice
putslx
putslxslice
putsnx
putsnxslice
putsolution
putsolutionyi
putstrparam
putsuc
putsucslice
putsux
putsuxslice
puttaskname
putvarbound
putvarboundlist
putvarboundlistconst
putvarboundslice
putvarboundsliceconst
putvarname
putvarsolutionj
putvartype
putvartypelist
putxc
putxcslice
putxx
putxxslice
puty
putyslice
readdata
readdataformat
readjsonstring
readlpstring
readopfstring
readparamfile
readptfstring
readsolution
readsummary
readtask
removebarvars
removecones
removecons
removevars
resizetask
sensitivityreport
setdefaults
setupthreads
solutiondef
solutionsummary
solvewithbasis
strtoconetype
strtosk
updatesolutioninfo
writedata
writejsonsol
writeparamfile
writesolution
writetask
```
